@@ -33,12 +33,6 @@ def log_integration(rows):
     from stratus_api.bigquery.bigquery import create_table
     from stratus_api.events import publish_event, create_topic
 
-    create_table(project_id=get_settings()['integration_log_project_id'],
-                 table_name=get_settings()['integration_log_table'],
-                 dataset_name=get_settings()['integration_log_dataset'],
-                 schema=INTEGRATION_LOG_SCHEMA)
-
-    create_topic(get_settings()['integration_log_topic'])
     errors = stream_records_to_bigquery(rows=rows, row_ids=None,
                                         project_id=get_settings()['integration_log_project_id'],
                                         table_name=get_settings()['integration_log_table'],
